Adding gaps support and more.
[xmenu] / config.h
index db81ae6..27e9c11 100644 (file)
--- a/config.h
+++ b/config.h
@@ -1,25 +1,28 @@
-/* font */
-static const char *font = "monospace:size=9";    /* for regular items */
+static struct Config config = {
+       /* font */
+       .font = "monospace:size=9", /* for regular items */
 
 
-/* colors */
-static const char *background_color = "#FFFFFF";
-static const char *foreground_color = "#2E3436";
-static const char *selbackground_color = "#3584E4";
-static const char *selforeground_color = "#FFFFFF";
-static const char *separator_color = "#CDC7C2";
-static const char *border_color = "#E6E6E6";
+       /* colors */
+       .background_color = "#FFFFFF",
+       .foreground_color = "#2E3436",
+       .selbackground_color = "#3584E4",
+       .selforeground_color = "#FFFFFF",
+       .separator_color = "#CDC7C2",
+       .border_color = "#E6E6E6",
 
 
-/* sizes in pixels */
-static int width_pixels = 130;      /* minimum width of a menu */
-static int height_pixels = 25;      /* height of a single menu item */
-static int border_pixels = 1;       /* menu border */
-static int separator_pixels = 3;    /* space around separator */
+       /* sizes in pixels */
+       .width_pixels = 130,        /* minimum width of a menu */
+       .height_pixels = 25,        /* height of a single menu item */
+       .border_pixels = 1,         /* menu border */
+       .separator_pixels = 3,      /* space around separator */
+       .gap_pixels = 0,            /* gap between menus */
 
 
-/* the variables below cannot be set by X resources */
+       /* the variables below cannot be set by X resources */
 
 
-/* geometry of the right-pointing isoceles triangle for submenus */
-static const int triangle_width = 3;
-static const int triangle_height = 7;
+       /* geometry of the right-pointing isoceles triangle for submenus */
+       .triangle_width = 3,
+       .triangle_height = 7,
 
 
-/* padding of the area around the icon */
-static const int iconpadding = 4;
+       /* padding of the area around the icon */
+       .iconpadding = 4,
+};